# Quickstart

## Requirements

* Python 3.12 to 3.13


## Installation

### Install from pypi:

This will install the latest release from pypi via pip:

```bash
pip install typerdrive
```


To include the runnable demo, you need to include the `demo` extra:

```bash
pip install typerdrive[demo]
```
